"""acatome-extract: PDF extraction pipeline for scientific papers."""

from importlib.metadata import version

from acatome_extract.bundle import read_bundle, write_bundle
from acatome_extract.pipeline import extract, extract_dir

__all__ = ["extract", "extract_dir", "read_bundle", "write_bundle"]
__version__ = version("acatome-extract")
